diff --git a/components/lib/datatable/DataTable.d.ts b/components/lib/datatable/DataTable.d.ts
index 34b22a3f29..6dadf7fe23 100755
--- a/components/lib/datatable/DataTable.d.ts
+++ b/components/lib/datatable/DataTable.d.ts
@@ -622,10 +622,6 @@ export interface DataTablePassThroughOptions {
* Uses to pass attributes to the footerr ow's DOM element.
*/
footerRow?: DataTablePassThroughOptionType;
- /**
- * Uses to pass attributes to the footer cell's DOM element.
- */
- footerCell?: DataTablePassThroughOptionType;
/**
* Uses to pass attributes to the resize helper's DOM element.
*/
diff --git a/components/lib/treetable/BodyCell.vue b/components/lib/treetable/BodyCell.vue
index a2b9166e51..a8ef88bedf 100644
--- a/components/lib/treetable/BodyCell.vue
+++ b/components/lib/treetable/BodyCell.vue
@@ -16,7 +16,7 @@
- {{ resolveFieldData(node.data, columnProp('field')) }}
+ {{ resolveFieldData(node.data, columnProp('field')) }}
diff --git a/components/lib/treetable/TreeTable.vue b/components/lib/treetable/TreeTable.vue
index 98c86a785d..f34324820d 100755
--- a/components/lib/treetable/TreeTable.vue
+++ b/components/lib/treetable/TreeTable.vue
@@ -65,9 +65,9 @@
>
-
+
-
+ |
|
@@ -96,7 +96,7 @@
>
-
+ |
|
diff --git a/components/lib/column/Column.d.ts b/components/lib/column/Column.d.ts
index 5d11ee4537..dbd5883c35 100755
--- a/components/lib/column/Column.d.ts
+++ b/components/lib/column/Column.d.ts
@@ -274,13 +274,13 @@ export interface ColumnPassThroughOptions {
*/
rowEditorInitIcon?: ColumnPassThroughOptionType;
/**
* Uses to pass attributes to the row editor edit button's DOM element.
*/
- rowEditorEditButton?: ColumnPassThroughOptionType;
+ rowEditorSaveButton?: ColumnPassThroughOptionType;
/**
* Uses to pass attributes to the row editor edit icon's DOM element.
*/
- rowEditorEditIcon?: ColumnPassThroughOptionType;
+ rowEditorSaveIcon?: ColumnPassThroughOptionType;
/**
* Uses to pass attributes to the row editor cancel button's DOM element.
*/
@@ -289,7 +289,14 @@ export interface ColumnPassThroughOptions {
* Uses to pass attributes to the row editor cancel icon's DOM element.
*/
rowEditorCancelIcon?: ColumnPassThroughOptionType;
-
+ /**
+ * Uses to pass attributes to the footer cell's DOM element.
+ */
+ footerCell?: ColumnPassThroughOptionType;
+ /**
+ * Uses to pass attributes to the body cell content's DOM element.
+ */
+ bodyCellContent?: ColumnPassThroughOptionType;
/**
* Uses to pass attributes to the hidden input wrapper's DOM element.
*/
@@ -274,13 +274,13 @@ export interface ColumnPassThroughOptions {
rowEditorInitIcon?: ColumnPassThroughOptionType;
/**
- * Uses to pass attributes to the row editor edit button's DOM element.
+ * Uses to pass attributes to the row editor save button's DOM element.
*/
@@ -274,13 +274,13 @@ export interface ColumnPassThroughOptions {
/**
- * Uses to pass attributes to the row editor edit icon's DOM element.
+ * Uses to pass attributes to the row editor save icon's DOM element.
*/
diff --git a/components/lib/treetable/TreeTable.d.ts b/components/lib/treetable/TreeTable.d.ts
index 3b39068130..2d2f0701b1 100755
--- a/components/lib/treetable/TreeTable.d.ts
+++ b/components/lib/treetable/TreeTable.d.ts
@@ -212,21 +212,29 @@ export interface TreeTablePassThroughOptions {
*/
headerRow?: TreeTablePassThroughOptionType;
/**
* Uses to pass attributes to the header cell's DOM element.
*/
- headerCell?: TreeTablePassThroughOptionType;
+ headerFilterRow?: TreeTablePassThroughOptionType;
+ /**
+ * Uses to pass attributes to the header filter cell's DOM element.
+ */
+ headerFilterCell?: TreeTablePassThroughOptionType;
/**
* Uses to pass attributes to the tbody's DOM element.
*/
tbody?: TreeTablePassThroughOptionType;
+ /**
+ * Uses to pass attributes to the row's DOM element.
+ */
+ row?: TreeTablePassThroughOptionType;
/**
* Uses to pass attributes to the empty message's DOM element.
*/
emptyMessage?: TreeTablePassThroughOptionType;
/**
* Uses to pass attributes to the body cell's DOM element.
*/
- bodyCell?: TreeTablePassThroughOptionType;
+ emptyMessageCell?: TreeTablePassThroughOptionType;
/**
* Uses to pass attributes to the tfoot's DOM element.
*/
@@ -243,46 +251,6 @@ export interface TreeTablePassThroughOptions {
* Uses to pass attributes to the resize helper's DOM element.
*/
resizeHelper?: TreeTablePassThroughOptionType;
- /**
- * Uses to pass attributes to the row toggler's DOM element.
- */
- rowToggler?: TreeTablePassThroughOptionType;
- /**
- * Uses to pass attributes to the row toggler icon's DOM element.
- */
- rowTogglerIcon?: TreeTablePassThroughOptionType;
- /**
- * Uses to pass attributes to the column resizer's DOM element.
- */
- columnResizer?: TreeTablePassThroughOptionType;
- /**
- * Uses to pass attributes to the sort badge's DOM element.
- */
- sortBadge?: TreeTablePassThroughOptionType;
- /**
- * Uses to pass attributes to the header title's DOM element.
- */
- headerTitle?: TreeTablePassThroughOptionType;
- /**
- * Uses to pass attributes to the checkbox wrapper's DOM element.
- */
- checkboxWrapper?: TreeTablePassThroughOptionType;
- /**
- * Uses to pass attributes to checkbox's DOM element.
- */
- checkbox?: TreeTablePassThroughOptionType;
- /**
- * Uses to pass attributes to the checkbox icon's DOM element.
- */
- checkboxIcon?: TreeTablePassThroughOptionType;
- /**
- * Uses to pass attributes to the hidden input wrapper's DOM element.
- */
- hiddenInputWrapper?: TreeTablePassThroughOptionType;
- /**
- * Uses to pass attributes to the hidden input's DOM element.
- */
- hiddenInput?: TreeTablePassThroughOptionType;
/**
* Uses to pass attributes to the Column helper components.
*/
@@ -212,21 +212,29 @@ export interface TreeTablePassThroughOptions {
headerRow?: TreeTablePassThroughOptionType;
/**
- * Uses to pass attributes to the header cell's DOM element.
+ * Uses to pass attributes to the header filter row's DOM element.
*/
@@ -212,21 +212,29 @@ export interface TreeTablePassThroughOptions {
emptyMessage?: TreeTablePassThroughOptionType;
/**
- * Uses to pass attributes to the body cell's DOM element.
+ * Uses to pass attributes to the empty message cell's DOM element.
*/